==> bs4Dash_0.4.0.tar.gz: bs4Dash/README.md <==
# bs4Dash <img src="https://rinterface.com/inst/images/bs4Dash.svg" width="200px" align="right"/>

[![Build Status](https://travis-ci.org/RinteRface/bs4Dash.svg?branch=master)](https://travis-ci.org/RinteRface/bs4Dash)
[![version](http://www.r-pkg.org/badges/version/bs4Dash)](https://CRAN.R-project.org/package=bs4Dash)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-ff69b4.svg)](https://www.tidyverse.org/lifecycle/#stable)
[![cranlogs](https://cranlogs.r-pkg.org/badges/bs4Dash)](https://CRAN.R-project.org/package=bs4Dash)
[![total](https://cranlogs.r-pkg.org/badges/grand-total/bs4Dash)](https://www.rpackages.io/package/bs4Dash)

> Bootstrap 4 shinydashboard using AdminLTE3

<br>

<div class="row">
<div class="col-sm-6" align="center">
<div class="card">
<a href="https://dgranjon.shinyapps.io/virtual_patient_v2/" target="_blank"><img src="https://community.rstudio.com/uploads/default/original/2X/e/eb1013fd09ccf10cbe13da3f0168eebfcb0eba75.gif"></a>
</div>
</div>
</div>

<br>

See a working example on shinyapps.io [here](https://dgranjon.shinyapps.io/bs4DashDemo/).

## Useful Informations (if any)

...

## Installation

This package is on CRAN:

```r
# from CRAN
install.packages("bs4Dash")
# latest devel version
devtools::install_github("RinteRface/bs4Dash")
```

## Demo

See a preview of the package [here](https://rinterface.com/shiny/bs4Dash/classic/) and
[here](https://rinterface.com/shiny/bs4Dash/old_school/) or run

```r
library(bs4Dash)
# classic theme
bs4DashGallery()
# old_school theme
bs4DashGallery(theme = "old_school")
```

An applied example can be found [here](https://rinterface.com/shiny/showcase/ratp/) (the 
original dashboard was made by [Philippine Rheins](https://twitter.com/PhilippineRs) 
from [dreamRs](https://twitter.com/dreamRs_fr)).

## Issues

Issues are listed [here](https://github.com/RinteRface/bs4Dash/issues).

==> bs4Dash_0.5.0.tar.gz: bs4Dash/README.md <==
# bs4Dash <img src="https://rinterface.com/inst/images/bs4Dash.svg" width="200px" align="right"/>

[![Build Status](https://travis-ci.org/RinteRface/bs4Dash.svg?branch=master)](https://travis-ci.org/RinteRface/bs4Dash)
[![version](http://www.r-pkg.org/badges/version/bs4Dash)](https://CRAN.R-project.org/package=bs4Dash)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-ff69b4.svg)](https://www.tidyverse.org/lifecycle/#stable)
[![cranlogs](https://cranlogs.r-pkg.org/badges/bs4Dash)](https://CRAN.R-project.org/package=bs4Dash)
[![total](https://cranlogs.r-pkg.org/badges/grand-total/bs4Dash)](https://www.rpackages.io/package/bs4Dash)

> Bootstrap 4 shinydashboard using AdminLTE3

<br>

<div class="row">
<div class="col-sm-6" align="center">
<div class="card">
<a href="https://dgranjon.shinyapps.io/virtual_patient_v2/" target="_blank"><img src="https://community.rstudio.com/uploads/default/original/2X/e/eb1013fd09ccf10cbe13da3f0168eebfcb0eba75.gif"></a>
</div>
</div>
</div>

<br>

See a working example on shinyapps.io [here](https://dgranjon.shinyapps.io/bs4DashDemo/).

## Useful Informations (if any)

...

## Installation

This package is on CRAN:

```r
# from CRAN
install.packages("bs4Dash")
# latest devel version
devtools::install_github("RinteRface/bs4Dash")
```

## Demo

See a preview of the package [here](https://rinterface.com/shiny/bs4Dash/classic/) and
[here](https://rinterface.com/shiny/bs4Dash/old_school/) or run

```r
library(bs4Dash)
# classic theme
bs4DashGallery()
# old_school theme
bs4DashGallery(theme = "old_school")
```

An applied example can be found [here](https://rinterface.com/shiny/showcase/ratp/) (the 
original dashboard was made by [Philippine Rheins](https://twitter.com/PhilippineRs) 
from [dreamRs](https://twitter.com/dreamRs_fr)).

## Issues

Issues are listed [here](https://github.com/RinteRface/bs4Dash/issues). 


## Akwnowledgement

I warmly thank [Glyphicons](https://www.glyphicons.com) creator for providing them free for Bootstrap.
